<?php
/**
 * Template part for displaying front page featured.
 *
 * @package Moral
 */

// Get default  mods value.
$featured = get_theme_mod( 'store_mall_featured', 'custom' );

if ( ! store_mall_is_woocommerce_activated() || 'disable' === $featured ) {
	return;
}

$default = store_mall_get_default_mods();
$section_title = get_theme_mod( 'store_mall_featured_title', $default['store_mall_featured_title'] );
$section_sub_title = get_theme_mod( 'store_mall_featured_sub_title', $default['store_mall_featured_sub_title'] );

?>
<div id="featured-products" class="relative page-section">
    <div class="wrapper">
        <div class="section-header">
        	<h2 class="section-title"><?php echo esc_html( $section_title ); ?></h2>
        	<p class="section-subtitle"><?php echo esc_html( $section_sub_title ); ?></p>
        </div><!-- .section-header -->

        <div class="section-content grid">
				<?php
				$featured_num = get_theme_mod( 'store_mall_featured_num', 6 );

				if (  in_array( $featured, array( 'recent-products', 'featured-products', 'product' ) ) ) {
					if ( 'recent-products' === $featured ) {
						$args = array( 'posts_per_page' => $featured_num );
					} elseif ( 'featured-products' === $featured ) {
						$args = array(
							'order'   => 'desc',
							'orderby' => 'date',
							'featured' => true,
							'posts_per_page' => absint( $featured_num ),
						);
					} else {
						$id_arr = array();
						for ( $i=1; $i <= $featured_num; $i++ ) { 
							$id = get_theme_mod( 'store_mall_featured_product_' . $i );
							if ( $id ) {
								$id_arr[] = $id;
							}
						}
						$args = array(
							'include' => $id_arr,
							'posts_per_page' => absint( $featured_num ),
                            'orderby'   => 'post__in',
						);
					}

	        	    $products = wc_get_products( $args );

					if ( $products ) {
	        	    	foreach ( $products as $product ) {
	        	    		$url = $product->get_permalink();
		        	        $thumbnail_id = $product->get_image_id();
		        	        $img_url = wp_get_attachment_url( $thumbnail_id );
		        	        $name  = $product->get_name();
							?>
				            <article class="grid-item">
							    <div class="featured-product-wrapper">
							        <a href="<?php echo esc_url( $url ); ?>">
							        	<?php echo woocommerce_get_product_thumbnail(); ?>
							        	<img src="<?php echo esc_url( $img_url );?>" alt="<?php echo esc_attr( $name );?>"></a>
							        <div class="featured-item-wrapper">
							            <header class="entry-header">
							                <h2 class="entry-title"><?php echo esc_html( $name );?></h2>
							            </header>
							            <a href="<?php echo esc_url( $url ); ?>" class="more-link">
							            	<?php esc_html_e( 'View Product', 'store-mall-pro' ); ?>
							                <?php echo store_mall_get_svg( array( 'icon' => 'arrow-right' ) ); ?>
							            </a>
							        </div><!-- .featured-item-wrapper -->
							    </div><!-- .featured-product-wrapper -->
							</article>
						<?php	
						}
						wp_reset_postdata();
					}
				} elseif( 'product-cat' === $featured ) { 
	        		for ( $i=1; $i <= $featured_num; $i++ ) { 
	        	        $cat_id = get_theme_mod( 'store_mall_featured_product_cat_' . $i );
	        	        if ( $cat_id ) :
	        	        	$term_link = get_term_link( (int)$cat_id, 'product_cat' );
	        	        	$term_obj = get_term_by( 'id', $cat_id, 'product_cat' );
	        	        	$term_name = $term_obj->name;
							?>
							<article class="grid-item">
							    <div class="featured-product-wrapper">
							        <a href="<?php echo esc_url( $term_link );?>"><img src="<?php echo esc_url( store_mall_get_cat_featured_img_url( $cat_id ) );?>" alt="<?php echo esc_attr( $term_name );?>"></a>
							        <div class="featured-item-wrapper">
							            <header class="entry-header">
							                <h2 class="entry-title"><?php echo esc_html( $term_name );?></h2>
							            </header>
							            <a href="<?php echo esc_url( $term_link ) ; ?>" class="more-link">
							            	<?php esc_html_e( 'View Products', 'store-mall-pro' ); ?>
							                <?php echo store_mall_get_svg( array( 'icon' => 'arrow-right' ) ); ?>
							            </a>
							        </div><!-- .featured-item-wrapper -->
							    </div><!-- .featured-product-wrapper -->
							</article>
						<?php
						endif;
					}
				}
				?>
            </div><!-- .section-content -->
    </div><!-- .wrapper -->
</div><!-- #featured-products -->