<?php
/**
 * Template part for displaying front page slider.
 *
 * @package Moral
 */

// Get default  mods value.
$slider = get_theme_mod( 'store_mall_slider', 'custom' );

if ( 'disable' === $slider ) {
    return;
}

$default = store_mall_get_default_mods();

$slider_num = get_theme_mod( 'store_mall_slider_num', 3 );
$opacity = get_theme_mod( 'store_mall_slider_overlay', 0 );
$slider_design = get_theme_mod( 'store_mall_slider_design', 'slider-one' );

if ( 'slider-two' === $slider_design ) : ?>
	 <div id="product-menu-wrapper" class="relative">
	    <div class="wrapper">
	        <div id="products-navigation">
	        	<?php if ( has_nav_menu( 'slider-menu' ) ) : ?>
                <span class="product-navigation-title">
                	<?php
                		$theme_locations = get_nav_menu_locations();
                		if ( isset( $theme_locations['slider-menu'] ) ) {
							$menu_obj = get_term( $theme_locations['slider-menu'], 'nav_menu' );
	                		echo esc_html( $menu_obj->name );
                		}
                	?>
                </span>
                <?php
                    wp_nav_menu( array(
                        'theme_location' => 'slider-menu',
                        'menu_class'     => '',
                        'container'     => '',
                        'container_class' => '',
                    ) );
                endif; ?>
	        </div><!-- #products-navigation -->
<?php endif; 

if ( 'slider-one' === $slider_design || 'slider-two' === $slider_design ) : ?>
	<div id="featured-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":true, "autoplay": true, "fade": false }'>
		<?php
		if (  in_array( $slider, array( 'post', 'page', 'cat' ) ) ) {

		    if ( 'cat' === $slider ) {
		        $cat_id = get_theme_mod( 'store_mall_slider_cat' );
		        $args = array(
		            'cat' => $cat_id,   
		            'posts_per_page' => $slider_num,
		        );
		    } else {
		        $id = array();
		        for ( $i=1; $i <= $slider_num; $i++ ) { 
		            $id[] = get_theme_mod( "store_mall_slider_{$slider}_" . $i );
		        }
		        $args = array(
		            'post_type' => $slider,
		            'post__in' => (array)$id,   
	                'orderby'   => 'post__in',
		            'posts_per_page' => $slider_num,
		            'ignore_sticky_posts' => true,
		        );
		    }

		    $query = new WP_Query( $args );

		    $j = 1;
		    if ( $query->have_posts() ) :
		        while ( $query->have_posts() ) :
		            $query->the_post();
		            ?>
		        
		            <article class="slick-item <?php echo ( $j == 1 ) ? 'display-block' : 'display-none'; ?>" style="background-image: url('<?php the_post_thumbnail_url( 'full' ); ?>');">
		            	<div style="opacity: <?php echo esc_attr( $opacity ); ?>" class="overlay"></div>
			            <div class="wrapper">
			                <div class="featured-content-wrapper">
			                	<div class="entry-meta">
			                        <span class="cat-links">
			                            <?php echo get_the_category_list( esc_html__( ', ', 'store-mall-pro' ) );?>
			                        </span><!-- .cat-links -->
			                    </div><!-- .entry-meta -->
			                    <header class="entry-header">
			                        <h2 class="entry-title"><?php the_title();?></h2>
			                    </header>
			                    <div class="entry-content">
			                    	<p><?php the_excerpt(); ?></p>
			                    </div>
			                    <?php 
			                    $custom_btn = get_theme_mod( 'store_mall_slider_custom_btn_' . $j, $default['store_mall_slider_custom_btn'] ); 
			                    if ( $custom_btn ) : ?>
				                    <div class="more-link">
				                        <a href="<?php the_permalink(); ?>" class="btn btn-primary"><span><?php echo esc_html( $custom_btn ); ?></span></a>
				                    </div><!-- .more-link -->
			                    <?php endif; ?>
			            	</div><!-- .featured-content-wrapper -->
			            </div><!-- .wrapper -->
	    	        </article>
		        <?php 
		        $j++;
		    	endwhile;
		        wp_reset_postdata();
		    endif; 
		} elseif( 'custom' === $slider ) {
		    for ( $i=1; $i <= $slider_num; $i++ ) { 
		        $img_url = get_theme_mod( 'store_mall_slider_image_' . $i );
		        $content   = get_theme_mod( 'store_mall_slider_custom_content_' . $i, $default['store_mall_slider_custom_content'] );
		        $btn_url = get_theme_mod( 'store_mall_slider_custom_link_' . $i, '#' );
		        $btn_txt = get_theme_mod( 'store_mall_slider_custom_btn_' . $i, $default['store_mall_slider_custom_btn'] );
		        
		        ?>
		        <article class="slick-item <?php echo ( $i == 1 ) ? 'display-block' : 'display-none'; ?>" style="background-image: url( <?php echo esc_url( $img_url );?> );">
		            <div style="opacity: <?php echo esc_attr( $opacity ); ?>" class="overlay"></div>
		            <div class="wrapper">
		                <div class="featured-content-wrapper">
		                    <header class="entry-header">
		                        <?php echo wp_kses_post( $content, $default['store_mall_slider_custom_content'] );?>
		                    </header>
		                    <?php if ( $btn_txt ) : ?>
			                    <div class="more-link">
			                        <a href="<?php echo esc_url( $btn_url ); ?>" class="btn btn-primary"><span><?php echo esc_html( $btn_txt ); ?></span></a>
			                    </div><!-- .more-link -->
		                    <?php endif; ?>
		                </div><!-- .featured-content-wrapper -->
		            </div><!-- .wrapper -->
		        </article>
		<?php   
		    }
		} elseif( 'product-cat' === $slider ) {
			for ( $i=1; $i <= $slider_num; $i++ ) { 
		        $cat_id = get_theme_mod( 'store_mall_slider_product_cat_' . $i );
		        if ( $cat_id ) :
	    	        $term_obj = get_term_by( 'id', $cat_id, 'product_cat' );
	    	        $btn_txt = get_theme_mod( 'store_mall_slider_custom_btn_' . $i, $default['store_mall_slider_custom_btn'] );
	    	        
	    	        ?>
	    	        <article class="slick-item <?php echo ( $i == 1 ) ? 'display-block' : 'display-none'; ?>" style="background-image: url( <?php echo esc_url( store_mall_get_cat_featured_img_url( $cat_id ) );?> );">
		            	<div style="opacity: <?php echo esc_attr( $opacity ); ?>" class="overlay"></div>
			            <div class="wrapper">
			                <div class="featured-content-wrapper">
			                    <header class="entry-header">
			                        <h2 class="entry-title"><?php echo esc_html( $term_obj->name );?></h2>
			                    </header>
			                    <div class="entry-content">
			                    	<?php echo esc_html( $term_obj->description );?>
			                    </div>
			                    <?php if ( $btn_txt ) : ?>
				                    <div class="more-link">
				                        <a href="<?php echo esc_url( get_term_link( (int)$cat_id, 'product_cat' ) ) ; ?>" class="btn btn-primary"><span><?php echo esc_html( $btn_txt ); ?></span></a>
				                    </div><!-- .more-link -->
			                    <?php endif; ?>
			                </div><!-- .featured-content-wrapper -->
			            </div><!-- .wrapper -->
	    	        </article>
		    	<?php
		    	endif;
		    }
		} elseif( in_array( $slider, array( 'recent-products', 'product' ) ) ) {
			if ( 'product' ===  $slider ) {
	    		$product_ids = array();
	    		for ( $i=1; $i <= $slider_num; $i++ ) { 
	    	        $product_id = get_theme_mod( 'store_mall_slider_product_' . $i );
	    	        if ( $product_id ) {
	    	        	$product_ids[] = $product_id;
	    	        }
	    	    }

	    	    $args = array( 'orderby'   => 'post__in', 'include' => $product_ids );
			} else {
	    	    $args = array( 'posts_per_page' => $slider_num );
			}
		    $products = wc_get_products( $args );
		    if ( $products ) :
		    	$j = 1;
		    	foreach ( $products as $product ) {
	    	        $thumbnail_id = $product->get_image_id();

	    	        $cat_ids = $product->get_category_ids();

	    	        $btn_txt = get_theme_mod( 'store_mall_slider_custom_btn_' . $j, $default['store_mall_slider_custom_btn'] );
	    	        
	    	        ?>
	    	        <article class="slick-item <?php echo ( $j == 1 ) ? 'display-block' : 'display-none'; ?>" style="background-image: url( <?php echo esc_url( wp_get_attachment_url( $thumbnail_id ) );?> );">
		            	<div style="opacity: <?php echo esc_attr( $opacity ); ?>" class="overlay"></div>
			            <div class="wrapper">
			                <div class="featured-content-wrapper">
		                		<div class="entry-meta">
		                	        <span class="cat-links">
		                	            <?php foreach ( $cat_ids as $cat_id ) { 
		                	            	$term_obj = get_term( $cat_id, '', OBJECT, 'raw' );
		                	            	?>
		                	        		<a href="<?php echo esc_url( get_term_link( $cat_id, 'product_cat' ) ); ?>"><?php echo esc_html( $term_obj->name ); ?></a>,
		                	            <?php 
		                	        	}
		                	        	?>
		                	        </span><!-- .cat-links -->
		                	    </div><!-- .entry-meta -->
			                    <header class="entry-header">
			                        <h2 class="entry-title"><?php echo esc_html( $product->get_title() );?></h2>
			                    </header>
			                    <div class="entry-content">
			                    	<p><?php echo esc_html( $product->get_short_description() ); ?></p>
			                    </div>
			                    <?php if ( $btn_txt ) : ?>
				                    <div class="more-link">
				                        <a href="<?php echo esc_url( $product->get_permalink() ); ?>" class="btn btn-primary"><span><?php echo esc_html( $btn_txt ); ?></span></a>
				                    </div><!-- .more-link -->
			                    <?php endif; ?>
			                </div><!-- .featured-content-wrapper -->
			            </div><!-- .wrapper -->
	    	        </article>
		    	<?php
		    	$j++;
		    	}
		    endif;
		}
		?>
	</div><!-- #featured-slider -->
<?php endif; 

if ( 'slider-two' === get_theme_mod( 'store_mall_slider_design', 'slider-one' ) ) : ?>
		</div><!-- .wrapper -->
	</div><!-- #product-slider -->
<?php endif;

if ( 'slider-three' === $slider_design ) : 
	require get_parent_theme_file_path( 'frontpage-parts/slider/three.php' ); 
endif;
