<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Moral
 */
?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="http://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'store-mall-pro' ); ?></a>
    
    <div class="menu-overlay"></div>

    <?php $default = store_mall_get_default_mods(); ?>
    
    <div id="top-navigation" class="col-2">
        <div class="wrapper">
            <div class="widget widget_contact_address">
                <ul>
                    <?php 
                    $phone_num = get_theme_mod( 'store_mall_header_phone', $default['store_mall_header_phone'] );
                    if ( $phone_num ) : 
                        ?>
                        <li class="phone">
                            <a href="#">
                            <?php echo store_mall_get_svg( array( 'icon' => 'phone' ) ); ?>
                            <span><?php echo esc_html( $phone_num ); ?></span>
                            </a>
                        </li>
                    <?php endif; ?>
                    <?php 
                    $email = get_theme_mod( 'store_mall_header_email', $default['store_mall_header_email'] );
                    if ( $email ) : ?>
                        <li class="message">
                            <a href="#">
                            <?php echo store_mall_get_svg( array( 'icon' => 'email' ) ); ?>
                            <span><?php echo esc_html( $email ); ?></span>
                            </a>
                        </li>
                    <?php endif; ?>
                </ul>
            </div><!-- .widget_contact_address -->
            <div class="widget widget_social_icons">
                <ul class="language-translater">
                    <li class="menu-item-has-children">
                        <?php if ( has_nav_menu( 'top' ) ) : ?>
                            <a href="#">
                                <?php echo esc_html( store_mall_get_menu_nam_by_location( 'top' ) ); ?>
                                <?php echo store_mall_get_svg( array( 'icon' => 'caret-down' ) ); ?>
                            </a>
                            <?php
                            wp_nav_menu( array(
                                'theme_location' => 'top',
                                'menu_class'     => 'sub-menu',
                                'container'     => '',
                                'container_class' => '',
                                'depth'          => 1,
                            ) );
                        endif; ?>
                    </li>
                </ul>

                <?php if ( has_nav_menu( 'social' ) ) :
                    wp_nav_menu( array(
                        'theme_location' => 'social',
                        'menu_class'     => 'social-icons',
                        'container'     => '',
                        'container_class' => '',
                        'depth'          => 1,
                        'link_before'    => '<span class="screen-reader-text">',
                        'link_after'     => '</span>' . store_mall_get_svg( array( 'icon' => 'chain' ) ),
                    ) );
                endif; ?>
                    
            </div><!-- .widget_social_icons -->
        </div><!-- .wrapper -->
    </div><!-- #top-navigation -->

    <?php
    $header_design = get_theme_mod( 'store_mall_header_design_option', 'header-one' ); 
    if ( 'header-one' === $header_design ) {
        require get_parent_theme_file_path( '/header/one.php' );
    } elseif ( 'header-two' === $header_design ) {
        require get_parent_theme_file_path( '/header/two.php' );
    }


    
