<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Moral
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function store_mall_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

    $header_design = get_theme_mod( 'store_mall_header_design_option', 'header-one' ); 
	if ( 'header-two' === $header_design ) {
		$classes[] = 'modern-menu';
	} else {
		$classes[] = 'classic-menu';
	}

	// When menu is sticky.
	$menu_sticky = get_theme_mod( 'store_mall_make_menu_sticky', false );
	if ( $menu_sticky ) {
		$classes[] = 'menu-sticky';
	}

	// When  color scheme is light or dark.
	$color_scheme = get_theme_mod( 'store_mall_color_scheme', 'lite' );
	$classes[] = esc_attr( $color_scheme ) . '-version';
	
	// When global archive layout is checked.
	if ( is_archive() || store_mall_is_latest_posts() || is_404() || is_search() ) {
		if ( store_mall_is_woocommerce_activated() && ( is_woocommerce() || is_shop() || is_product_category() || is_product_tag() ) ) {
			if ( ! is_active_sidebar( 'woocommerce' ) ) {
				$classes[] = 'no-sidebar';
			} else {
				$archive_sidebar = get_theme_mod( 'store_mall_woo_global_archive_sidebar', 'right' ); 
				$classes[] = esc_attr( $archive_sidebar ) . '-sidebar';
			}
		} else {
			if ( ! is_active_sidebar( 'sidebar-1' ) ) {
				$classes[] = 'no-sidebar';
			} else {
				$archive_sidebar = get_theme_mod( 'store_mall_archive_sidebar', 'right' ); 
				$classes[] = esc_attr( $archive_sidebar ) . '-sidebar';
			}
		}
	} else if ( is_single() ) { // When global post sidebar is checked.
		if ( store_mall_is_woocommerce_activated() && ( is_woocommerce() || is_product() ) ) {
			if ( ! is_active_sidebar( 'woocommerce' ) ) {
				$classes[] = 'no-sidebar';
			} else {
				$store_mall_post_sidebar_meta = get_post_meta( get_the_ID(), 'store-mall-select-sidebar', true );
		    	if ( ! empty( $store_mall_post_sidebar_meta ) ) {
					$classes[] = esc_attr( $store_mall_post_sidebar_meta ) . '-sidebar';
		    	} else {
					$global_post_sidebar = get_theme_mod( 'store_mall_woo_global_singular_layout', 'right' ); 
					$classes[] = esc_attr( $global_post_sidebar ) . '-sidebar';
		    	}
			}
	    } else {
	    	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
				$classes[] = 'no-sidebar';
			} else {
	    		$store_mall_post_sidebar_meta = get_post_meta( get_the_ID(), 'store-mall-select-sidebar', true );
		    	if ( ! empty( $store_mall_post_sidebar_meta ) ) {
					$classes[] = esc_attr( $store_mall_post_sidebar_meta ) . '-sidebar';
		    	} else {
					$global_post_sidebar = get_theme_mod( 'store_mall_global_post_layout', 'right' ); 
					$classes[] = esc_attr( $global_post_sidebar ) . '-sidebar';
		    	}
		    }
	    }
	} elseif ( store_mall_is_frontpage_blog() || is_page() ) {
		if ( store_mall_is_woocommerce_activated() && ( is_woocommerce() || is_cart() || is_checkout() || is_account_page() ) ) {
			if ( ! is_active_sidebar( 'woocommerce' ) ) {
				$classes[] = 'no-sidebar';
			} else {
				$store_mall_post_sidebar_meta = get_post_meta( get_the_ID(), 'store-mall-select-sidebar', true );
		    	if ( ! empty( $store_mall_post_sidebar_meta ) ) {
					$classes[] = esc_attr( $store_mall_post_sidebar_meta ) . '-sidebar';
		    	} else {
					$global_post_sidebar = get_theme_mod( 'store_mall_woo_global_singular_layout', 'right' ); 
					$classes[] = esc_attr( $global_post_sidebar ) . '-sidebar';
		    	}
		    }
	    } else {
	    	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
				$classes[] = 'no-sidebar';
			} else {
				if ( store_mall_is_frontpage_blog() ) {
					$page_id = get_option( 'page_for_posts' );
				} else {
					$page_id = get_the_ID();
				}

		    	$store_mall_page_sidebar_meta = get_post_meta( $page_id, 'store-mall-select-sidebar', true );
				if ( ! empty( $store_mall_page_sidebar_meta ) ) {
					$classes[] = esc_attr( $store_mall_page_sidebar_meta ) . '-sidebar';
				} else {
					$global_page_sidebar = get_theme_mod( 'store_mall_global_page_layout', 'right' ); 
					$classes[] = esc_attr( $global_page_sidebar ) . '-sidebar';
				}
			}
	    }
	} 

	// Site layout classes
	$site_layout = get_theme_mod( 'store_mall_site_layout', 'wide' );
	$classes[] = esc_attr( $site_layout ) . '-layout';

	return $classes;
}
add_filter( 'body_class', 'store_mall_body_classes' );

function store_mall_post_classes( $classes ) {
	if ( store_mall_is_page_displays_posts() ) {
		// Search 'has-post-thumbnail' returned by default and remove it.
		$key = array_search( 'has-post-thumbnail', $classes );
		unset( $classes[ $key ] );
		
		$archive_img_enable = get_theme_mod( 'store_mall_enable_archive_featured_img', true );

		if( has_post_thumbnail() && $archive_img_enable ) {
			$classes[] = 'has-post-thumbnail';
		} else {
			$classes[] = 'no-post-thumbnail';
		}
	}

  $classes[] = 'animated animatedFadeInUp';
  
	return $classes;
}
add_filter( 'post_class', 'store_mall_post_classes' );

/**
 * Excerpt length
 * 
 * @since Moral 1.0.0
 * @return Excerpt length
 */
function store_mall_excerpt_length( $length ){
	if ( is_admin() ) {
		return $length;
	}

	$length = get_theme_mod( 'store_mall_archive_excerpt_length', 60 );
	return $length;
}
add_filter( 'excerpt_length', 'store_mall_excerpt_length', 999 );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function store_mall_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'store_mall_pingback_header' );

/**
 * Get an array of post id and title.
 * 
 */
function store_mall_get_post_choices() {
	$choices = array( '' => esc_html__( '--Select--', 'store-mall-pro' ) );
	$args = array( 'numberposts' => -1, );
	$posts = get_posts( $args );

	foreach ( $posts as $post ) {
		$id = $post->ID;
		$title = $post->post_title;
		$choices[ $id ] = $title;
	}

	return $choices;
}

/**
 * Get an array of cat id and title.
 * 
 */
function store_mall_get_post_cat_choices() {
  $choices = array( '' => esc_html__( '--Select--', 'store-mall-pro' ) );
	$cats = get_categories();

	foreach ( $cats as $cat ) {
		$id = $cat->term_id;
		$title = $cat->name;
		$choices[ $id ] = $title;
	}

	return $choices;
}

/**
 * Get an array of google fonts.
 * 
 */
function store_mall_font_choices() {
	$font_family_arr = array();
	$font_family_arr[''] = esc_html__( '--Default--', 'store-mall-pro' );

	// Make the request
    $request = wp_remote_get( get_theme_file_uri( 'assets/uploads/webfonts.json' ) );

    if( is_wp_error( $request ) ) {
    	return false; // Bail early
    }
	// Retrieve the data
    $body = wp_remote_retrieve_body( $request );
    $data = json_decode( $body );
    if ( ! empty( $data ) ) {
    	foreach ( $data->items as $items => $fonts ) {
    		$family_str_arr = explode( ' ', $fonts->family );
    		$family_value = implode( '-', array_map( 'strtolower', $family_str_arr ) );
    		$font_family_arr[ $family_value ] = $fonts->family;
    	}
    }

    return apply_filters( 'store_mall_font_choices', $font_family_arr );
}

/**
 * Checks to see if we're on the homepage or not.
 */
function store_mall_is_frontpage() {
	return ( is_front_page() && ! is_home() );
}

/**
 * Checks to see if Static Front Page is set to "Your latest posts".
 */
function store_mall_is_latest_posts() {
	return ( is_front_page() && is_home() );
}

/**
 * Checks to see if Static Front Page is set to "Posts page".
 */
function store_mall_is_frontpage_blog() {
	return ( is_home() && ! is_front_page() );
}

/**
 * Checks to see if the current page displays any kind of post listing.
 */
function store_mall_is_page_displays_posts() {
	return ( store_mall_is_frontpage_blog() || is_search() || is_archive() || store_mall_is_latest_posts() );
}

/**
 * Shows a breadcrumb for all types of pages.  This is a wrapper function for the Breadcrumb_Trail class,
 * which should be used in theme templates.
 *
 * @since  1.0.0
 * @access public
 * @param  array $args Arguments to pass to Breadcrumb_Trail.
 * @return void
 */
function store_mall_breadcrumb( $args = array() ) {
	$breadcrumb = apply_filters( 'breadcrumb_trail_object', null, $args );

	if ( ! is_object( $breadcrumb ) )
		$breadcrumb = new Breadcrumb_Trail( $args );

	return $breadcrumb->trail();
}

/**
 * Pagination in archive/blog/search pages.
 */
function store_mall_posts_pagination() { 
	$archive_pagination = get_theme_mod( 'store_mall_archive_pagination_type', 'numeric' );
	if ( 'disable' === $archive_pagination ) {
		return;
	}
	if ( 'numeric' === $archive_pagination ) {
		the_posts_pagination( array(
            'prev_text'          => store_mall_get_svg( array( 'icon' => 'left-arrow' ) ) . '<span class="meta-nav screen-reader-text">' . esc_html__( 'Previous', 'store-mall-pro' ).'</span>',
            'next_text'          => '<span class="meta-nav screen-reader-text">' . esc_html__( 'Next', 'store-mall-pro' ) .'</span>' . store_mall_get_svg( array( 'icon' => 'left-arrow' ) ),
        ) );
	} elseif ( 'older_newer' === $archive_pagination ) {
        the_posts_navigation( array(
            'prev_text'          => '<span class="icon">' . store_mall_get_svg( array( 'icon' => 'left-arrow' ) ) . '</span><span>'. esc_html__( 'Older', 'store-mall-pro' ) .'</span>',
            'next_text'          => '<span class="icon">' . store_mall_get_svg( array( 'icon' => 'left-arrow' ) ) . '</span><span>'. esc_html__( 'Newer', 'store-mall-pro' ) .'</span>',
        )  );
	}
}

function store_mall_get_svg_by_url( $url = false ) {
	if ( ! $url ) {
		return false;
	}

	$social_icons = store_mall_social_links_icons();

	foreach ( $social_icons as $attr => $value ) {
		if ( false !== strpos( $url, $attr ) ) {
			return store_mall_get_svg( array( 'icon' => esc_attr( $value ) ) );
		}
	}
}

function store_mall_custom_color_scheme() {
    
    $color = get_theme_mod( 'store_mall_custom_color_scheme', '#49bcd9' );

    $h1_h6_font_family = explode( '-', get_theme_mod( 'store_mall_h1_h6_font_option'  ) );
    $h1_h6_font_family = implode( ' ', array_map( 'ucfirst', $h1_h6_font_family ) );

    $body_font_family = explode( '-', get_theme_mod( 'store_mall_body_font_option'  ) );
    $body_font_family = implode( ' ', array_map( 'ucfirst', $body_font_family ) );
    
    $slider_head_color = get_theme_mod( 'store_mall_slider_heading_color', '#000' );
    $custom_css = '';

    if ( 'custom' === get_theme_mod( 'store_mall_color_scheme' ) ) {
    	$custom_css .= '
           	/*----------------------------------------
           		Color
           	------------------------------------------*/
           	a,
           	.widget_contact_address ul li a:hover,
			.widget_contact_address ul li a:focus,
			ul.language-translater > li.menu-item-has-children > ul li a:hover,
			.site-title a:hover,
			.site-title a:focus,
			.main-navigation ul#primary-menu li.current-menu-item > a,
			.main-navigation ul#primary-menu li:hover > a,
			.main-navigation ul#primary-menu li:focus > a,
			.main-navigation a:hover,
			.main-navigation a:focus,
			.main-navigation ul.nav-menu > li > a:hover,
			.main-navigation ul.nav-menu > li > a:focus,
			.pagination .page-numbers.current,
			.pagination .page-numbers:hover,
			.pagination .page-numbers:focus,
			#secondary ul li a:hover,
			#secondary ul li a:focus,
			.widget_popular_post h3 a:hover,
			.widget_popular_post h3 a:focus,
			.widget_popular_post a:hover time,
			.widget_popular_post a:focus time,
			.widget_latest_post h3 a:hover,
			.widget_latest_post h3 a:focus,
			.widget_latest_post a:hover time,
			.widget_latest_post a:focus time,
			.page-header small,
			.post-categories a,
			.post-categories a:hover,
			.post-categories a:focus,
			.single-post-wrapper span.tags-links a:hover,
			.single-post-wrapper span.tags-links a:focus,
			.single-post-wrapper span.cat-links a:hover,
			.single-post-wrapper span.cat-links a:focus,
			.reply a:hover,
			.reply a:focus,
			.comment-meta .url:hover,
			.comment-meta .url:focus,
			.comment-metadata a,
			.comment-metadata a time,
			.comment-metadata a:hover,
			.comment-metadata a:focus,
			.comment-metadata a:hover time,
			.comment-metadata a:focus time,
			.btn-default:hover,
			.btn-default:focus,
			#products-navigation a:hover,
			#products-navigation a:focus,
			#featured-products article .featured-item-wrapper .more-link:hover,
			.product-meta .cat-links a:hover,
			.product-meta .cat-links a:focus,
			.woocommerce-loop-product__title:hover,
			.woocommerce-loop-product__title:focus,
			.woocommerce ul.products li.product a:hover .woocommerce-loop-category__title, 
			.woocommerce ul.products li.product a:hover .woocommerce-loop-product__title, 
			.woocommerce ul.products li.product a:hover h3,
			.woocommerce ul.products li.product a:focus .woocommerce-loop-category__title, 
			.woocommerce ul.products li.product a:focus .woocommerce-loop-product__title, 
			.woocommerce ul.products li.product a:focus h3,
			.price ins .woocommerce-Price-amount, 
			.price .woocommerce-Price-amount,
			#call-to-action .section-title span,
			.product-filtering ul li.active a,
			.woocommerce ul.cart_list li a:hover, 
			.woocommerce ul.product_list_widget li a:hover,
			.woocommerce ul.cart_list li a:focus, 
			.woocommerce ul.product_list_widget li a:focus,
			.blog-posts-wrapper .cat-links a,
			.blog-posts-wrapper .cat-links,
			.blog-posts-wrapper .entry-container .entry-title a:hover,
			.blog-posts-wrapper .entry-container .entry-title a:focus,
			.blog-posts-wrapper .featured-image .entry-meta a:hover,
			.blog-posts-wrapper .featured-image .entry-meta a:focus,
			.posted-on a:hover,
			.posted-on a:focus,
			.blog-posts-wrapper .more-link:hover,
			.blog-posts-wrapper .more-link:focus,
			.yith-wcwl-add-button.hide .fa,
			.woocommerce ul.products li.product .product_meta .posted_in a:hover,
			.woocommerce ul.products li.product .product_meta .posted_in a:focus,
			.woocommerce nav.woocommerce-pagination ul li a:focus, 
			.woocommerce nav.woocommerce-pagination ul li a:hover, 
			.woocommerce nav.woocommerce-pagination ul li span.current,
			.woocommerce div.product span.posted_in a:hover,
			.woocommerce div.product span.posted_in a:focus,
			.woocommerce div.product .yith-wcwl-add-button.hide a.add_to_wishlist:before,
			.woocommerce div.product .woocommerce-tabs ul.tabs li.active a,
			.woocommerce #review_form #respond .form-submit input[type="submit"]:hover,
			.woocommerce #review_form #respond .form-submit input[type="submit"]:focus,
			.woocommerce div.product .woocommerce-tabs ul.tabs li a:hover,
			.woocommerce-MyAccount-content .woocommerce-Button.button:hover,
			.woocommerce-MyAccount-content button.woocommerce-Button.button:hover,
			.woocommerce-MyAccount-content button.woocommerce-Button.button:focus,
			.woocommerce-MyAccount-content button.woocommerce-Button.button:hover,
			.woocommerce .cart .button:hover, 
			.woocommerce .cart input.button:hover,
			.woocommerce #respond input#submit.disabled:hover, 
			.woocommerce #respond input#submit:disabled:hover, 
			.woocommerce #respond input#submit:disabled[disabled]:hover, 
			.woocommerce a.button.disabled:hover, 
			.woocommerce a.button:disabled:hover, 
			.woocommerce a.button:disabled[disabled]:hover, 
			.woocommerce button.button.disabled:hover, 
			.woocommerce button.button:disabled:hover, 
			.woocommerce button.button:disabled[disabled]:hover, 
			.woocommerce input.button.disabled:hover, 
			.woocommerce input.button:disabled:hover, 
			.woocommerce input.button:disabled[disabled]:hover,
			.woocommerce-MyAccount-content button.woocommerce-Button.button:focus,
			.woocommerce .cart .button:focus, 
			.woocommerce .cart input.button:focus,
			.woocommerce #respond input#submit.disabled:focus, 
			.woocommerce #respond input#submit:disabled:focus, 
			.woocommerce #respond input#submit:disabled[disabled]:focus, 
			.woocommerce a.button.disabled:focus, 
			.woocommerce a.button:disabled:focus, 
			.woocommerce a.button:disabled[disabled]:focus, 
			.woocommerce button.button.disabled:focus, 
			.woocommerce button.button:disabled:focus, 
			.woocommerce button.button:disabled[disabled]:focus, 
			.woocommerce input.button.disabled:focus, 
			.woocommerce input.button:disabled:focus, 
			.woocommerce input.button:disabled[disabled]:focus,
			#add_payment_method .wc-proceed-to-checkout a.checkout-button:hover, 
			.woocommerce-cart .wc-proceed-to-checkout a.checkout-button:hover, 
			.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button:hover,
			#add_payment_method .wc-proceed-to-checkout a.checkout-button:focus, 
			.woocommerce-cart .wc-proceed-to-checkout a.checkout-button:focus, 
			.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button:focus,
			.woocommerce #respond input#submit.alt:hover, 
			.woocommerce a.button.alt:hover, 
			.woocommerce button.button.alt:hover, 
			.woocommerce input.button.alt:hover,
			.woocommerce #respond input#submit.alt:focus, 
			.woocommerce a.button.alt:focus, 
			.woocommerce button.button.alt:focus, 
			.woocommerce input.button.alt:focus,
			.woocommerce-page .woocommerce-message .button:hover,
			.woocommerce-page .woocommerce-message .button:focus,
			.woocommerce #review_form #respond .form-submit input:hover,
			.woocommerce #review_form #respond .form-submit input:focus,
			.woocommerce form.login .button.woocommerce-Button.button:hover,
			.woocommerce form.login .button.woocommerce-Button.button:focus,
			form.woocommerce-ResetPassword.lost_reset_password .button.woocommerce-Button.button:hover,
			form.woocommerce-ResetPassword.lost_reset_password .button.woocommerce-Button.button:focus,
			.woocommerce #respond input#submit:hover, 
			.woocommerce a.button:hover, 
			.woocommerce button.button:hover, 
			.woocommerce input.button:hover,
			.woocommerce #respond input#submit:focus, 
			.woocommerce a.button:focus, 
			.woocommerce button.button:focus, 
			.woocommerce input.button:focus,
			.woocommerce-info::before,
			.woocommerce-message::before,
			.navigation.post-navigation a:hover, 
			.navigation.posts-navigation a:hover, 
			.navigation.post-navigation a:focus, 
			.navigation.posts-navigation a:focus,
			#infinite-handle span button:hover,
			#infinite-handle span button:focus {
           	    color: ' . esc_attr( $color ) . ';
           	}
           	.backtotop,
           	#respond input[type="submit"]:hover,
			#respond input[type="submit"]:focus,
			.main-navigation .cart-count a,
			#secondary .widget_search form.search-form button.search-submit,
			#colophon .widget_search form.search-form button.search-submit,
			input[type="submit"]:hover,
			input[type="submit"]:focus,
			#secondary .jetpack_subscription_widget input[type="submit"]:hover,
			#secondary .jetpack_subscription_widget input[type="submit"]:focus,
			.blog-posts .post-categories,
			.single-post-wrapper .entry-meta,
			.author-name:after,
			.btn-default,
			.btn-primary:before, 
			.btn-primary:before,
			.btn-primary:hover:before, 
			.btn-primary:focus:before,
			.slick-prev:hover,
			.slick-next:hover,
			.product-navigation-title,
			.product-filtering ul li.active a:after,
			.slick-dots li.slick-active button:before,
			.slick-dots li button:hover:before,
			#subscribe-us,
			.woocommerce div.product form.cart .button:hover,
			.woocommerce div.product form.cart .button:focus,
			.woocommerce #review_form #respond .form-submit input[type="submit"],
			.woocommerce-MyAccount-content button.woocommerce-Button.button,
			.woocommerce .cart .button, 
			.woocommerce .cart input.button,
			.woocommerce #respond input#submit.disabled, 
			.woocommerce #respond input#submit:disabled, 
			.woocommerce #respond input#submit:disabled[disabled], 
			.woocommerce a.button.disabled, 
			.woocommerce a.button:disabled, 
			.woocommerce a.button:disabled[disabled], 
			.woocommerce button.button.disabled, 
			.woocommerce button.button:disabled, 
			.woocommerce button.button:disabled[disabled], 
			.woocommerce input.button.disabled, 
			.woocommerce input.button:disabled, 
			.woocommerce input.button:disabled[disabled],
			#add_payment_method .wc-proceed-to-checkout a.checkout-button, 
			.woocommerce-cart .wc-proceed-to-checkout a.checkout-button, 
			.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button,
			.woocommerce #respond input#submit.alt, 
			.woocommerce a.button.alt, 
			.woocommerce button.button.alt, 
			.woocommerce input.button.alt,
			.woocommerce-page .woocommerce-message .button,
			.woocommerce #review_form #respond .form-submit input,
			.woocommerce form.login .button.woocommerce-Button.button,
			form.woocommerce-ResetPassword.lost_reset_password .button.woocommerce-Button.button,
			.woocommerce #respond input#submit, 
			.woocommerce a.button, 
			.woocommerce button.button, 
			.woocommerce input.button,
			.woocommerce-MyAccount-content .woocommerce-Button.button,
			.woocommerce-store-notice, 
			p.demo_store,
			#infinite-handle span button,
			.widget_product_search button[type="submit"]
 			{
           	    background-color: ' . esc_attr( $color ) . ';
           	}
           	.pagination .page-numbers.current,
			.pagination .page-numbers:hover,
			.pagination .page-numbers:focus,
			.single-post-wrapper span.tags-links a:hover,
			.single-post-wrapper span.tags-links a:focus,
			.btn-primary,
			.btn-default,
			.btn-default:hover,
			.btn-default:focus,
			.slick-prev:hover,
			.slick-next:hover,
			#featured-slider .slick-prev:hover, 
			#featured-slider .slick-next:hover,
			.slick-dots li button:before,
			.woocommerce .woocommerce-ordering select:focus,
			.woocommerce nav.woocommerce-pagination ul li a:focus, 
			.woocommerce nav.woocommerce-pagination ul li a:hover, 
			.woocommerce nav.woocommerce-pagination ul li span.current,
			.woocommerce #review_form #respond .form-submit input[type="submit"]:hover,
			.woocommerce #review_form #respond .form-submit input[type="submit"]:focus,
			#respond input[type="submit"],
			.woocommerce div.product form.cart .button,
			.woocommerce #review_form #respond .form-submit input[type="submit"],
			.woocommerce-MyAccount-content button.woocommerce-Button.button,
			.woocommerce .cart .button, 
			.woocommerce .cart input.button,
			.woocommerce #respond input#submit.disabled, 
			.woocommerce #respond input#submit:disabled, 
			.woocommerce #respond input#submit:disabled[disabled], 
			.woocommerce a.button.disabled, 
			.woocommerce a.button:disabled, 
			.woocommerce a.button:disabled[disabled], 
			.woocommerce button.button.disabled, 
			.woocommerce button.button:disabled, 
			.woocommerce button.button:disabled[disabled], 
			.woocommerce input.button.disabled, 
			.woocommerce input.button:disabled, 
			.woocommerce input.button:disabled[disabled],
			#add_payment_method .wc-proceed-to-checkout a.checkout-button, 
			.woocommerce-cart .wc-proceed-to-checkout a.checkout-button, 
			.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button,
			.woocommerce #respond input#submit.alt, 
			.woocommerce a.button.alt, 
			.woocommerce button.button.alt, 
			.woocommerce input.button.alt,
			.woocommerce-page .woocommerce-message .button,
			.woocommerce #review_form #respond .form-submit input,
			.woocommerce form.login .button.woocommerce-Button.button,
			form.woocommerce-ResetPassword.lost_reset_password .button.woocommerce-Button.button,
			.woocommerce #respond input#submit, 
			.woocommerce a.button, 
			.woocommerce button.button, 
			.woocommerce input.button,
			.woocommerce-MyAccount-content .woocommerce-Button.button,
			.woocommerce div.product div.images .flex-control-thumbs li img:hover,
			.woocommerce div.product div.images .flex-control-thumbs li img.flex-active,
			.main-navigation form.search-form,
			#infinite-handle span button,
			#infinite-handle span button:hover,
			#infinite-handle span button:focus {
           	    border-color: ' . esc_attr( $color ) . ';
           	}
			.woocommerce-info,
			.woocommerce-message {
				border-top-color: ' . esc_attr( $color ) . ';
			}
           	.woocommerce div.product .woocommerce-tabs ul.tabs li.active,
           	.modern-menu .main-navigation .search-cart-wrapper ul#site-header-cart .widget_shopping_cart a,
           	#search:before {
           	    border-bottom-color: ' . esc_attr( $color ) . ';
           	}
           	.widget_contact_address ul li a:hover svg,
			.widget_contact_address ul li a:focus svg,
			.main-navigation .search-cart-wrapper li.user-login a:hover svg,
			.main-navigation .search-cart-wrapper li.wishlist a:hover svg,
			.main-navigation ul#primary-menu li:hover > svg,
			.main-navigation ul#primary-menu li:focus > svg,
			.main-navigation li.menu-item-has-children:hover > a > svg,
			.main-navigation li.menu-item-has-children > a:hover > svg,
			.main-navigation li.menu-item-has-children > a:focus > svg,
			.main-navigation ul#primary-menu > li.current-menu-item > a > svg,
			.main-navigation ul.nav-menu > li > a.search:hover svg.icon-search,
			.main-navigation ul.nav-menu > li > a.search:focus svg.icon-search,
			.main-navigation li.search-menu a:hover svg,
			.main-navigation li.search-menu a:focus svg,
			.main-navigation li.search-menu a.search-active svg,
			.pagination .page-numbers.prev:hover svg, 
			.pagination .page-numbers.next:hover svg,
			.widget_search form.search-form button.search-submit:hover svg,
			.widget_search form.search-form button.search-submit:focus svg,
			.single-post-wrapper span.posted-on svg,
			.single-post-wrapper span.cat-links svg,
			#featured-products article .featured-item-wrapper .more-link svg,
			.blog-posts-wrapper .more-link svg,
			.navigation.post-navigation a:hover svg, 
			.navigation.posts-navigation a:hover svg, 
			.navigation.post-navigation a:focus svg, 
			.navigation.posts-navigation a:focus svg {
           	    fill: ' . esc_attr( $color ) . ';
           	}
           	@media screen and (min-width: 1024px) {
	           	#search-product form.search-form button.search-submit,
	           	.main-navigation ul.sub-menu li:hover > a,
				.main-navigation ul.sub-menu li:focus > a {
			    	background-color: ' . esc_attr( $color ) . ';
			  	}
			  	.modern-menu .main-navigation ul.sub-menu li:hover > a, 
	  			.modern-menu .main-navigation ul.sub-menu li:focus > a,
	  			.modern-menu .main-navigation ul#primary-menu ul li.current-menu-item > a, 
				.modern-menu .main-navigation ul#primary-menu ul li:hover > a, 
				.modern-menu .main-navigation ul#primary-menu ul li:focus > a {
	           	    color: ' . esc_attr( $color ) . ';
	           	}
				.main-navigation ul ul {
					border-top-color: ' . esc_attr( $color ) . ';
				}
				.main-navigation ul.nav-menu > li.menu-item-has-children:hover > a:after {
					border-bottom-color: ' . esc_attr( $color ) . ';
				}
			}
			@media screen and (min-width: 567px) {
				.woocommerce #content div.product .woocommerce-tabs ul.tabs li.active, 
				.woocommerce div.product .woocommerce-tabs ul.tabs li.active, 
				.woocommerce-page #content div.product .woocommerce-tabs ul.tabs li.active, 
				.woocommerce-page div.product .woocommerce-tabs ul.tabs li.active {
			   	    border-bottom-color: ' . esc_attr( $color ) . ';
			   	}
			}';
	}
		$custom_css .= '
		/*----------------------------------------
       		Font Family
       	------------------------------------------*/
       	h1,
		h2,
		h3,
		h4,
		h5,
		h6,
		.post-navigation a, 
		.posts-navigation a,
		.single-post-wrapper span.tags-links,
		.single-post-wrapper span.cat-links,
		.blog-posts-wrapper .cat-links a,
		.blog-posts-wrapper .cat-links,
		.woocommerce div.product .woocommerce-tabs ul.tabs li a {
			font-family: ' . esc_attr( $h1_h6_font_family ) . ';
		}
		body,
		.single-post-wrapper span.tags-links a,
		.single-post-wrapper span.cat-links a,
		.blog-posts-wrapper span.cat-links,
		.blog-posts-wrapper span.cat-links a,
		.blog-posts-wrapper span.cat-links,
		.blog-posts-wrapper span.cat-links a {
			font-family: ' . esc_attr( $body_font_family ) . ';
		}
		#featured-slider h2,
		ul.featured-content-list h2,
		#featured-modern-slider .featured-content-wrapper .entry-title,
		.featured-content-wrapper .cat-links a {
			color: ' . esc_attr( $slider_head_color ) . ';
		}
		#featured-slider p,
		#featured-modern-slider .featured-content-wrapper .entry-content p {
			color: ' . esc_attr( $slider_head_color ) . ';
		}
        ';
    wp_add_inline_style( 'store-mall-pro-style', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'store_mall_custom_color_scheme' );

// Add auto p to the palces where get_the_excerpt is being called.
add_filter( 'get_the_excerpt', 'wpautop' );

/**
 * Get menu name by theme location
 */
function store_mall_get_menu_nam_by_location( $menu_location ) {
    $locations = get_nav_menu_locations();
    $menu_obj = wp_get_nav_menu_object( $locations[ $menu_location ] );
    return $menu_obj->name;
}

if ( ! function_exists( 'store_mall_is_woocommerce_activated' ) ) {
	/**
	 * Query WooCommerce activation
	 */
	function store_mall_is_woocommerce_activated() {
		return class_exists( 'WooCommerce' ) ? true : false;
	}
}

if ( ! function_exists( 'store_mall_is_yww_activate' ) ) {
	/**
	 * Check if YITH WooCommerce Wishlist is activated.
	 */
	function store_mall_is_yww_activate() {
		return class_exists( 'YITH_WCWL' ) ? true : false;
	}
}

/**
 * Count number of widgets in a sidebar
 * Used to add classes to widget areas so widgets can be displayed one, two, three or four per row
 */
/**
 * Count number of widgets in a sidebar
 * Used to add classes to widget areas so widgets can be displayed one, two, three or four per row
 * @param  string $sidebar_id Sidebar widget area id.
 * @return int             Number of widgets in the sidebar
 */
function store_mall_count_widgets( $sidebar_id = '' ) {
	if ( empty( $sidebar_id ) ) {
		return false;
	}
	// If loading from front page, consult $_wp_sidebars_widgets rather than options
	// to see if wp_convert_widget_settings() has made manipulations in memory.
	// global $_wp_sidebars_widgets;
	// if ( empty( $_wp_sidebars_widgets ) ) :
	// 	$_wp_sidebars_widgets = get_option( 'sidebars_widgets', array() );
	// endif;
	
	$sidebars_widgets_count = get_option( 'sidebars_widgets', array() );
	
	if ( isset( $sidebars_widgets_count[ $sidebar_id ] ) ) :
		$widget_count = count( $sidebars_widgets_count[ $sidebar_id ] );
		return $widget_count;
	else:
		return false;
	endif;
}